@@ -111,6 +111,27 @@ nautilus_get_user_directory (void)
 	return user_directory;
 }
 
+/**
+ * nautilus_get_accel_map_file:
+ * 
+ * Get the path for the filename containing nautilus accelerator map.
+ * The filename need not exist.
+ *
+ * Return value: the filename path, or NULL if the home directory could not be found
+ **/
+char *
+nautilus_get_accel_map_file (void)
+{
+	const gchar *home;
+
+	home = g_get_home_dir();
+	if (home != NULL) {
+		return g_build_filename (home, ".gnome2/accels/nautilus", NULL);
+	}
+
+	return NULL;
+}
+
 typedef struct {
 	char *type;
 	char *path;
