@@ -3,7 +3,7 @@
 
 #include <glib-object.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
-#include <gdk/gdktypes.h>
+#include <gdk/gdk.h>
 #include <gio/gio.h>
 #include <gtk/gtk.h>
 
@@ -58,6 +58,7 @@ NautilusIconInfo *    nautilus_icon_info_lookup                       (GIcon
 								       int                size);
 NautilusIconInfo *    nautilus_icon_info_lookup_from_name             (const char        *name,
 								       int                size);
+gboolean              nautilus_icon_info_is_fallback                  (NautilusIconInfo  *icon);
 GdkPixbuf *           nautilus_icon_info_get_pixbuf                   (NautilusIconInfo  *icon);
 GdkPixbuf *           nautilus_icon_info_get_pixbuf_nodefault         (NautilusIconInfo  *icon);
 GdkPixbuf *           nautilus_icon_info_get_pixbuf_nodefault_at_size (NautilusIconInfo  *icon,
@@ -82,7 +83,6 @@ guint nautilus_icon_get_larger_icon_size             (guint              size);
 guint nautilus_icon_get_smaller_icon_size            (guint              size);
 
 gint  nautilus_get_icon_size_for_stock_size          (GtkIconSize        size);
-char *nautilus_icon_get_emblem_icon_by_name          (const char        *emblem_name);
 guint nautilus_icon_get_emblem_size_for_icon_size    (guint              size);
 
 
