@@ -87,18 +87,6 @@ is_local_file_a_link (const char *uri)
 	return link;
 }
 
-static gboolean
-is_link_data (const char *file_contents, int file_size)
-{
-	char *mimetype;
-	gboolean res;
-
-	mimetype = g_content_type_guess (NULL, file_contents, file_size, NULL);
-	res =  is_link_mime_type (mimetype);
-	g_free (mimetype);
-	return res;
-}
-
 static gboolean
 _g_key_file_load_from_gfile (GKeyFile *key_file,
 			     GFile *file,
@@ -293,10 +281,27 @@ nautilus_link_local_create (const char     *directory_uri,
 	return TRUE;
 }
 
+static const char *
+get_language (void)
+{
+	const char * const *langs_pointer;
+	int i;
+
+	langs_pointer = g_get_language_names ();
+	for (i = 0; langs_pointer[i] != NULL; i++) {
+		/* find first without encoding */
+		if (strchr (langs_pointer[i], '.') == NULL) {
+		return langs_pointer[i];
+		}
+	}
+	return NULL;
+} 
+
 static gboolean
 nautilus_link_local_set_key (const char *uri,
 			     const char *key,
-			     const char *value)
+			     const char *value,
+			     gboolean    localize)
 {
 	gboolean success;
 	GKeyFile *key_file;
@@ -309,11 +314,15 @@ nautilus_link_local_set_key (const char *uri,
 		g_object_unref (file);
 		return FALSE;
 	}
-
-	g_key_file_set_locale_string (key_file,
-				      MAIN_GROUP,
-				      key,
-				      NULL, value);
+	if (localize) {
+		g_key_file_set_locale_string (key_file,
+					      MAIN_GROUP,
+					      key,
+					      get_language (), 
+					      value);
+	} else {
+		g_key_file_set_string (key_file, MAIN_GROUP, key, value);
+	}
 	
 	
 	success = _g_key_file_save_to_gfile (key_file,  file, NULL);
@@ -326,7 +335,7 @@ gboolean
 nautilus_link_local_set_text (const char *uri,
 			      const char *text)
 {
-	return nautilus_link_local_set_key (uri, "Name", text);
+	return nautilus_link_local_set_key (uri, "Name", text, TRUE);
 }
 
 
@@ -334,7 +343,7 @@ gboolean
 nautilus_link_local_set_icon (const char        *uri,
 			      const char        *icon)
 {
-	return nautilus_link_local_set_key (uri, "Icon", icon);
+	return nautilus_link_local_set_key (uri, "Icon", icon, FALSE);
 }
 
 char *
@@ -534,10 +543,6 @@ nautilus_link_get_link_info_given_file_contents (const char  *file_contents,
 	char **only_show_in;
 	char **not_show_in;
 
-	if (!is_link_data (file_contents, link_file_size)) {
-		return;
-	}
-
 	key_file = g_key_file_new ();
 	if (!g_key_file_load_from_data (key_file,
 					file_contents,
