@@ -44,8 +44,6 @@
 #include <eel/eel-vfs-extensions.h>
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
-#include <libgnomeui/gnome-stock-icons.h>
-#include <libgnomeui/gnome-uidefs.h>
 #include <libnautilus-private/nautilus-icon-dnd.h>
 #include <libnautilus-private/nautilus-clipboard.h>
 #include <stdio.h>
@@ -259,6 +257,7 @@ label_button_pressed_callback (GtkWidget             *widget,
 			       GdkEventButton        *event)
 {
 	NautilusNavigationWindow *window;
+	NautilusWindowSlot       *slot;
 	NautilusView             *view;
 	GtkWidget                *label;
 
@@ -267,7 +266,8 @@ label_button_pressed_callback (GtkWidget             *widget,
 	}
 
 	window = nautilus_location_bar_get_window (widget->parent);
-	view = NAUTILUS_WINDOW (window)->content_view;
+	slot = NAUTILUS_WINDOW (window)->details->active_slot;
+	view = slot->content_view;
 	label = GTK_BIN (widget)->child;
 	/* only pop-up if the URI in the entry matches the displayed location */
 	if (view == NULL ||
@@ -302,6 +302,21 @@ set_position_and_selection_to_end (GtkEditable *editable)
 	gtk_editable_set_position (editable, end);
 }
 
+static void
+editable_activate_callback (GtkEntry *entry,
+			    gpointer user_data)
+{
+	NautilusNavigationBar *bar;
+	const char *entry_text;
+
+	bar = NAUTILUS_NAVIGATION_BAR (user_data);
+
+	entry_text = gtk_entry_get_text (entry);
+	if (entry_text != NULL && *entry_text != '\0') {
+		nautilus_navigation_bar_location_changed (bar);
+	}
+}
+
 static void
 editable_event_after_callback (GtkEntry *entry,
 			       GdkEvent *event,
@@ -400,8 +415,7 @@ nautilus_location_bar_init (NautilusLocationBar *bar)
 	event_box = gtk_event_box_new ();
 	gtk_event_box_set_visible_window (GTK_EVENT_BOX (event_box), FALSE);
 	
-	gtk_container_set_border_width (GTK_CONTAINER (event_box),
-					GNOME_PAD_SMALL);
+	gtk_container_set_border_width (GTK_CONTAINER (event_box), 4);
 	label = gtk_label_new (LOCATION_LABEL);
 	gtk_container_add   (GTK_CONTAINER (event_box), label);
 	gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_RIGHT);
@@ -409,14 +423,12 @@ nautilus_location_bar_init (NautilusLocationBar *bar)
 	g_signal_connect (label, "style_set", 
 			  G_CALLBACK (style_set_handler), NULL);
 
-	gtk_box_pack_start (GTK_BOX (hbox), event_box, FALSE, TRUE,
-			    GNOME_PAD_SMALL);
+	gtk_box_pack_start (GTK_BOX (hbox), event_box, FALSE, TRUE, 4);
 
 	entry = nautilus_location_entry_new ();
 	
 	g_signal_connect_object (entry, "activate",
-				 G_CALLBACK (nautilus_navigation_bar_location_changed),
-				 bar, G_CONNECT_SWAPPED);
+				 G_CALLBACK (editable_activate_callback), bar, 0);
 	g_signal_connect_object (entry, "event_after",
 				 G_CALLBACK (editable_event_after_callback), bar, G_CONNECT_AFTER);
 
